@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -272,6 +272,7 @@ public class FormatData_bs_Cyrl extends ListResourceBundle {
                     "\u0422\u0430\u0438\u0448\u043e",
                     "\u0428\u043e\u0432\u0430",
                     "\u0425\u0430\u0438\u0441\u0435\u0438",
+                    "",
                 }
             },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
@@ -339,6 +340,25 @@ public class FormatData_bs_Cyrl extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "\u0412\u0440\u0435\u043c\u0435 \u0443 \u0437\u0435\u043c\u0459\u0438: {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0",
+                    "00 \u0445\u0438\u0459",
+                    "000 \u0445\u0438\u0459",
+                    "0 \u043c\u0438\u043b",
+                    "00 \u043c\u0438\u043b",
+                    "000 \u043c\u0438\u043b",
+                    "0 \u043c\u043b\u0440\u0434",
+                    "00 \u043c\u043b\u0440\u0434",
+                    "000 \u043c\u043b\u0440\u0434",
+                    "0 \u0431\u0438\u043b",
+                    "00 \u0431\u0438\u043b",
+                    "000 \u0431\u0438\u043b",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -395,6 +415,25 @@ public class FormatData_bs_Cyrl extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0",
+                    "00\u00a0\u0445\u0438\u0459",
+                    "000\u00a0\u0445\u0438\u0459",
+                    "0\u00a0\u043c\u0438\u043b",
+                    "00\u00a0\u043c\u0438\u043b",
+                    "000\u00a0\u043c\u0438\u043b",
+                    "0\u00a0\u043c\u043b\u0440\u0434",
+                    "00\u00a0\u043c\u043b\u0440\u0434",
+                    "000\u00a0\u043c\u043b\u0440\u0434",
+                    "0\u00a0\u0431\u0438\u043b",
+                    "00\u00a0\u0431\u0438\u043b",
+                    "000\u00a0\u0431\u0438\u043b",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "DatePatterns",
                 new String[] {
@@ -450,6 +489,7 @@ public class FormatData_bs_Cyrl extends ListResourceBundle {
                     "\u0422\u0430\u0438\u0448\u043e",
                     "\u0428\u043e\u0432\u0430",
                     "\u0425\u0430\u0438\u0441\u0435\u0438",
+                    "",
                 }
             },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
